aboutsummaryrefslogtreecommitdiffstats
path: root/packet-frame.c
diff options
context:
space:
mode:
authorguy <guy@f5534014-38df-0310-8fa8-9805f1628bb7>2002-01-08 07:17:55 +0000
committerguy <guy@f5534014-38df-0310-8fa8-9805f1628bb7>2002-01-08 07:17:55 +0000
commite6a156eeda7a54efd09b4b79a60b1259cffd50cd (patch)
tree4b28e7419457af85fe159b5c2289e1d764abc267 /packet-frame.c
parent77c8544ce5bdb6c9a6f839e2f546cbaa2dba221a (diff)
If a ReportedBoundsError exception occurs, report it as a "malformed
packet" rather than a "malformed frame" - the packet in question might be part of a link-layer frame or might span more than one link-layer frame. git-svn-id: http://anonsvn.wireshark.org/wireshark/trunk@4497 f5534014-38df-0310-8fa8-9805f1628bb7
Diffstat (limited to 'packet-frame.c')
-rw-r--r--packet-frame.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/packet-frame.c b/packet-frame.c
index 2f2b35bc5b..951844a2a2 100644
--- a/packet-frame.c
+++ b/packet-frame.c
@@ -2,7 +2,7 @@
*
* Top-most dissector. Decides dissector based on Wiretap Encapsulation Type.
*
- * $Id: packet-frame.c,v 1.16 2001/12/24 17:06:53 gerald Exp $
+ * $Id: packet-frame.c,v 1.17 2002/01/08 07:17:55 guy Exp $
*
* Ethereal - Network traffic analyzer
* By Gerald Combs <gerald@ethereal.com>
@@ -158,9 +158,9 @@ dissect_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
}
CATCH(ReportedBoundsError) {
if (check_col(pinfo->cinfo, COL_INFO))
- col_append_str(pinfo->cinfo, COL_INFO, "[Malformed Frame]");
+ col_append_str(pinfo->cinfo, COL_INFO, "[Malformed Packet]");
proto_tree_add_protocol_format(tree, proto_malformed, tvb, 0, 0,
- "[Malformed Frame: %s]", pinfo->current_proto );
+ "[Malformed Packet: %s]", pinfo->current_proto );
}
ENDTRY;
}
@@ -222,10 +222,10 @@ proto_register_frame(void)
proto_set_cant_disable(proto_frame);
proto_short = proto_register_protocol("Short Frame", "Short frame", "short");
- proto_malformed = proto_register_protocol("Malformed Frame",
- "Malformed frame", "malformed");
+ proto_malformed = proto_register_protocol("Malformed Packet",
+ "Malformed packet", "malformed");
- /* "Short Frame" and "Malformed Frame" aren't really protocols,
+ /* "Short Frame" and "Malformed Packet" aren't really protocols,
they're error indications; disabling them makes no sense. */
proto_set_cant_disable(proto_short);
proto_set_cant_disable(proto_malformed);